@@ -94,6 +94,8 @@ sub match_regions {
     my %arg = @_;
     my $pattern = $arg{pattern} // croak "Parameter error";
     my $regex = ref $pattern eq 'Regexp' ? $pattern : qr/$pattern/m;
+    return &match_regions_by_group($regex) if $arg{group};
+
     my @regions;
 
     no warnings 'utf8';
@@ -111,6 +113,24 @@ sub match_regions {
     @regions;
 }
 
+sub match_regions_by_group {
+    my $regex = shift;
+    my @regions;
+
+    no warnings 'utf8';
+
+    while (/$regex/g) {
+	if (@- == 1) {
+	    push @regions, [ $-[0], $+[0] ];
+	} else {
+	    for my $i (1 .. $#-) {
+		push @regions, [ $-[$i], $+[$i], $i - 1];
+	    }
+	}
+    }
+    @regions;
+}
+
 sub classify_regions {
     my $opt = ref $_[0] eq 'HASH' ? shift : {};
 
